﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using BCS.Sym3;
using BCS;
using BCS.Sym3.Operator.Runtime;

namespace Sym3.Example.Gauge
{
    public partial class GaugeVertical : UserControl, BCS.Sym3.IHostedControl, IBindingNotification
    {
        ISym3OperatorClient client;

        string m_tagName = "";
        int m_min = 0;
        int m_max = 100;

        Panel panelBlack = new Panel();

        public GaugeVertical()
        {
            InitializeComponent();
            this.BackColor = Color.Green;

            panelBlack.Dock = DockStyle.Top;
            panelBlack.BackColor = Color.Black;
            panelBlack.Height = 0;
            this.Controls.Add(panelBlack);



        }

        #region IHostedControl Members

        public new void Load(ControlRunningMode mode, ISym3OperatorClient client, ISym3OperatorEditor editor, string parameters)
        {
            this.client = client;
            if (mode == ControlRunningMode.Run)
            {
                // split parameters:
                //tag=Tag1;min=0;max=100
                string[] strs = parameters.Split(';');
                foreach (string s in strs)
                {
                    string[] array = s.Split('=');
                    if (array[0] == "tag")
                        m_tagName = array[1];
                    if (array[0] == "min")
                        m_min = int.Parse(array[1]);
                    if (array[0] == "max")
                        m_max = int.Parse(array[1]);
                }

                ICallerHolder callerHolder = this.TopLevelControl as ICallerHolder;
                SubscribeLiveValue((callerHolder != null) ? callerHolder.Caller : null);
            }
        }

        public void BeforeDispose()
        {
        }

        #endregion

        #region IBindingNotification Members

        public void SubscribeLiveValue(object caller)
        {
            if (client == null) return;
            if (client.Project == null) return;

            if (client.Project.LiveValueService == null) return;

            //-- subscribe to live value service
            client.Project.LiveValueService.Subscribe(this, m_tagName, m_tagName);
        }

        public void UnsubscribeLiveValue()
        {
            if (client == null) return;
            if (client.Project == null) return;
            if (client.Project.LiveValueService == null) return;

            client.Project.LiveValueService.Unsubscribe(this);
        }

        public bool SetLiveValue(string propertyName, object value)
        {
            return true;
        }

        public bool GetLiveValue(string propertyName, out object value, out BCS.Quality quality, bool useTagValue = false)
        {
            quality = Quality.BAD;
            value = null;
            return false;
        }

        public void UpdateBinding(string propertyName, int index, object value, BCS.Quality quality)
        {
            if (m_tagName == propertyName)
            {
                SetValue(m_tagName, value);
                return;
            }
        }

        #endregion

        private void SetValue(string tagName, object value)
        { 
            if(value == null) return;

            double d = 0.0;
            Double.TryParse(value.ToString(), out d);

            d -= m_min;
            int currentMax = m_max -  m_min;
            panelBlack.Height = this.Height - ((int)((double)this.Height * d / (double)currentMax));
        }
    }
}
